@@ -50,7 +50,7 @@ class ViewMapAddModify {
         );
         $attrDefs = $this->MAPCFG->getValidObjectType($this->object_type);
         foreach ($_REQUEST as $attr => $val) {
-            // $_REQUEST might contain cookie infos. Skipt them.
+            // $_REQUEST might contain cookie infos. Skip them.
             if (isset($_COOKIE[$attr]))
                 continue;
             if (substr($attr, 0, 7) == 'toggle_' || substr($attr, 0, 1) == '_' || isset($exclude[$attr]))
@@ -155,7 +155,7 @@ class ViewMapAddModify {
 
                 $this->validateAttributes();
 
-                // Update the map configuration   
+                // Update the map configuration
                 if($this->mode == 'view_params') {
                     // Only modify/add the given attributes. Don't remove any
                     // set options in the array
@@ -441,6 +441,9 @@ class ViewMapAddModify {
             case 'text':
                 input($propname, $value, '', $hideField);
             break;
+            case 'textarea':
+                textarea($propname, $value, '', $hideField);
+            break;
         }
 
         // Try to split too long values in chunks
@@ -621,5 +624,10 @@ class ViewMapAddModify {
 
         return ob_get_clean();
     }
+
+    public function object_type()
+    {
+        return $this->object_type;
+    }
 }
 ?>
